netapp_ontap.models.zapp_s3_bucket_application_components API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.zapp_s3_bucket_application_components`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ZappS3BucketApplicationComponentsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ZappS3BucketApplicationComponents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `access_policies GET POST`

    The list of S3 objectstore policies to be created.

  `capacity_tier GET POST`

    Prefer lower latency storage under similar media costs.

  `comment GET POST`

    Object Store Server Bucket Description Usage: <(size 1..256)>

  `exclude_aggregates GET POST`

    The exclude_aggregates field of the zapp_s3_bucket_application_components.

  `name GET POST PATCH`

    The name of the application component.

  `qos GET POST`

    The qos field of the zapp_s3_bucket_application_components.

  `size GET POST PATCH`

    The total size of the S3 Bucket, split across the member components. Usage: {<integer>[KB|MB|GB|TB|PB]}

  `storage_service GET POST PATCH`

    The storage_service field of the zapp_s3_bucket_application_components.

  `uuid GET`

    Object Store Server Bucket UUID Usage: <UUID>